@@ -1213,7 +1213,7 @@ kbhit (void)
   if (FD_ISSET (0, &read_fd)) /* character pending on stdin */
     return 1;
 
-/* no charcaters were pending */
+/* no characters were pending */
 
   return 0;
 }
@@ -1286,7 +1286,8 @@ terminate ()
     }
   if (debugmode > 1)
     fprintf (dbg, "\n closing debug file\n");
-  fclose (dbg);
+  if (debugmode > 0)
+    fclose (dbg);
   exit (0);
 }
 
